diff src/edit.c @ 19147:06ef1e438ac8 v8.2.0133

patch 8.2.0133: invalid memory access with search command Commit: https://github.com/vim/vim/commit/98a336dd497d3422e7efeef9f24cc9e25aeb8a49 Author: Bram Moolenaar <Bram@vim.org> Date: Mon Jan 20 20:22:30 2020 +0100 patch 8.2.0133: invalid memory access with search command Problem: Invalid memory access with search command. Solution: When :normal runs out of characters in bracketed paste mode break out of the loop.(closes #5511)
author Bram Moolenaar <Bram@vim.org>
date Mon, 20 Jan 2020 20:30:04 +0100
parents bcbc9fe665b5
children f12eda320c78
line wrap: on
line diff
--- a/src/edit.c
+++ b/src/edit.c
@@ -4959,9 +4959,9 @@ bracketed_paste(paste_mode_T mode, int d
 	do
 	    c = vgetc();
 	while (c == K_IGNORE || c == K_VER_SCROLLBAR || c == K_HOR_SCROLLBAR);
-	if (c == NUL || got_int)
+	if (c == NUL || got_int || (ex_normal_busy > 0 && c == Ctrl_C))
 	    // When CTRL-C was encountered the typeahead will be flushed and we
 	    // won't get the end sequence.
 	    break;
 
 	if (has_mbyte)
@@ -4959,9 +4959,9 @@ bracketed_paste(paste_mode_T mode, int d
 	    // When CTRL-C was encountered the typeahead will be flushed and we
-	    // won't get the end sequence.
+	    // won't get the end sequence.  Except when using ":normal".
 	    break;
 